# Jupyter Community Call 10/25

**Date:** October 25, 2022, at 7am Pacific (in your [timezone](https://arewemeetingyet.com/Los%20Angeles/2022-10-25/7:00/Jupyter%20Community%20Call))

[**Discourse**](https://discourse.jupyter.org/t/jupyter-community-calls/668)
[**Youtube**](https://youtu.be/RHGYVTYI1bg)

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- These notes will be recorded and posted [here](https://jupyter.readthedocs.io/en/latest/community/community-call-notes/index.html)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

* Shout out to all the cats and kittens on the call!
* **Sarah** JupyterHub is participating in Outreachy and has lots of applicants!
* **Isabela** Earlier this month, a group of people met to do [keyboard navigation manual tests on the Jupyter Notebook 7 prerelease](https://github.com/jupyter/notebook/issues/6595). It was great to have people meeting to work on accessibility.
* **Steve** Python 3.11 was released yesterday.

## Agenda Items

* **Jan-Hendrik Müller, Ricky Alinsky**: A new perspective on creating example galleries from notebooks.
    * Plywood gallery (and its VS Code extension!)
    * https://discourse.jupyter.org/t/plywood-gallery-generate-python-documentation-via-notebooks/16510
* **deathbeds**: a bike shed means blood shed
    * "when markdown and python collide" - https://tonyfast.github.io/tonyfast/run/lab/index.html?path=xxii/oct/2022-10-21-markdown-future.ipynb?room=deathbeds-more-like-deft-breads
        * https://github.com/tonyfast/midgy
        * https://github.com/deathbeds/pidgy
        * https://github.com/deathbeds/importnb
        * https://github.com/tonyfast/tonyfast
    * "Spooky-ber Note-boo-ks" with [jupyterlab-deck](https://github.com/deathbeds/jupyterlab-deck) and a history of presenting in notebooks and a reporting deck (with Robot Framework).
* **Debra Chen, Niko Zeng**: Invitation for joint-holding community meetup

## Other Links Shared

This is a space to store links shared during community call discussions related to or separate from the agenda items.

- [Open Source Design Discourse](https://discourse.opensourcedesign.net/)
- [Jupyter Discourse](https://discourse.jupyter.org/)

## Attendees 

|   Name   |           Institution     | GitHub Handle|
|----------|---------------------------|--------------|
|     Jan-Hendrik Müller     |      University of Göttingen      |  @kolibril13
| Ricky M. Alinsky | GUSTO University | @Rickaym
| Steve Silvester | MongoDB | @blink1073 |
|     Debra Chen     |   DolphinScheduler community         |@debrachena 
| Sarah Gibson | 2i2c | @sgibson91 
| Isabela Presedo-Floyd | Quansight Labs | @isabela-pf 

Plus 7 more.
